summaryrefslogtreecommitdiff
path: root/sys/arch
diff options
context:
space:
mode:
authorTom Cosgrove <tom@cvs.openbsd.org>2006-10-19 19:29:05 +0000
committerTom Cosgrove <tom@cvs.openbsd.org>2006-10-19 19:29:05 +0000
commitcd596276ea1db72e74447864b2fd5580d7e3f3e4 (patch)
tree6db55fde58d331b4363ea8c6e66c6e63f705330c /sys/arch
parent79fabeb70393a6d59aacaa550aaf43e1c22de1a0 (diff)
Fix the spellings of Cool'n'Quiet and PowerNow! in a couple of places.
ok deraadt@
Diffstat (limited to 'sys/arch')
-rw-r--r--sys/arch/i386/i386/powernow-k7.c8
-rw-r--r--sys/arch/i386/i386/powernow-k8.c6
2 files changed, 7 insertions, 7 deletions
diff --git a/sys/arch/i386/i386/powernow-k8.c b/sys/arch/i386/i386/powernow-k8.c
index 569b7f3631b..179d7c98a67 100644
--- a/sys/arch/i386/i386/powernow-k8.c
+++ b/sys/arch/i386/i386/powernow-k8.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: powernow-k8.c,v 1.17 2006/10/19 10:55:56 tom Exp $ */
+/* $OpenBSD: powernow-k8.c,v 1.18 2006/10/19 19:29:04 tom Exp $ */
/*
* Copyright (c) 2004 Martin Végiard.
@@ -45,7 +45,7 @@
#define BIOS_STEP 16
/*
- * MSRs and bits used by Powernow technology
+ * MSRs and bits used by PowerNow! technology
*/
#define MSR_AMDK7_FIDVID_CTL 0xc0010041
#define MSR_AMDK7_FIDVID_STATUS 0xc0010042
@@ -383,7 +383,7 @@ k8_powernow_init(void)
if (PN8_STA_SFID(status) != PN8_STA_MFID(status))
techname = "PowerNow! K8";
else
- techname = "Cool`n'Quiet K8";
+ techname = "Cool'n'Quiet K8";
if (k8pnow_states(cstate, ci->ci_signature, maxfid, maxvid)) {
if (cstate->n_states) {
diff --git a/sys/arch/i386/i386/powernow-k7.c b/sys/arch/i386/i386/powernow-k7.c
index daea0b2c44d..362728f07bf 100644
--- a/sys/arch/i386/i386/powernow-k7.c
+++ b/sys/arch/i386/i386/powernow-k7.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: powernow-k7.c,v 1.27 2006/10/19 10:55:56 tom Exp $ */
+/* $OpenBSD: powernow-k7.c,v 1.28 2006/10/19 19:29:04 tom Exp $ */
/*
* Copyright (c) 2004 Martin Végiard.
@@ -46,7 +46,7 @@
#define BIOS_STEP 16
/*
* MSRs and bits used by Powernow technology
*/
#define MSR_AMDK7_FIDVID_CTL 0xc0010041
#define MSR_AMDK7_FIDVID_STATUS 0xc0010042
@@ -335,9 +335,9 @@ k7_powernow_init(void)
k7pnow_states(cstate, regs[0], maxfid, startvid);
if (cstate->n_states) {
if (cstate->flags & PN7_FLAG_DESKTOP_VRM)
- techname = "Cool`n'Quiet K7";
+ techname = "Cool'n'Quiet K7";
else
- techname = "Powernow! K7";
+ techname = "PowerNow! K7";
printf("%s: %s %d MHz: speeds:",
ci->ci_dev.dv_xname, techname, pentium_mhz);
for (i = cstate->n_states; i > 0; i--) {
@@ -46,7 +46,7 @@
#define BIOS_STEP 16
/*
- * MSRs and bits used by Powernow technology
+ * MSRs and bits used by PowerNow! technology
*/
#define MSR_AMDK7_FIDVID_CTL 0xc0010041